@@ -171,17 +171,19 @@ class ParametersCOSIM:
     def makeGenericIOPortFiles(self, CoilSections, CurrentFolder, CoSimFolder: str, PSpiceExecutable: str, LEDETExecutable: str,
                                t_0 = [0, 2e-5], t_end = [2e-5, 0.5], t_step_max = [[1e-5, 1e-5], [1e-5, 1e-5]],
                                relTolerance = [1e-4, None], absTolerance = [1, None], executionOrder = [1, 2],
-                               executeCleanRun = [True, True], N_LEDET = 1):
+                               executeCleanRun = [True, True], N_LEDET = 1, SimulationNumber = [0]):
 
         # Components which are used in the Ports
         Components = ["L", "CoilSections"]  # [0] = PSpice, [1]=LEDET
         # Setting the Coilsections
         CSections = []
+        LSections = []
         for i in range(len(CoilSections)):
             CSectionsPerPort = []
             for j in range(len(CoilSections[i])):
                 CSectionsPerPort.append(Components[1] + "_" + str(CoilSections[i][j]))
             CSections.append(CSectionsPerPort)
+            LSections.append(Components[0] + "_" + str(i+1))
 
         # Variables used for convergence, for now its the first magnet current and the LEDET Voltages
         if N_LEDET == 1:
@@ -253,6 +255,7 @@ class ParametersCOSIM:
                 data = json.load(f)
                 data["solverPath"] = LEDETExecutable
                 data["modelName"] = self.nameMagnet
+                data["simulationNumber"] = str(SimulationNumber[0])
             try:
                 os.remove(filename)
             except:
@@ -260,12 +263,16 @@ class ParametersCOSIM:
             with open(filename, 'w') as f:
                 json.dump(data, f, indent=4)
         else:
+            if len(SimulationNumber) != N_LEDET:
+                SimulationNumber = [0]*N_LEDET
+                print("Simulation Number 0 is used for all LEDET models")
             for i in range(1,N_LEDET+1):
                 filename = self.nameFolderCosimModel + '/LEDET_'+str(i)+'/LedetConfig.json'
                 with open(filename, 'r') as f:
                     data = json.load(f)
                     data["solverPath"] = LEDETExecutable
                     data["modelName"] = self.nameMagnet[i-1]
+                    data["simulationNumber"] = str(SimulationNumber[i-1])
                 try:
                     os.remove(filename)
                 except:
@@ -375,7 +382,7 @@ class ParametersCOSIM:
                 for j in range(2):  # 2Ports in PSpice
                     struct = {}
                     struct["name"] = "Port_" + str(i+n*len(CoilSections)+1) + "_" + str(j)
-                    struct["components"] = [Components[0] + "_" + str(i+n*len(CoilSections)+1)]
+                    struct["components"] = [LSections(i)]
                     struct["inputs"] = []
                     for l in range(len(couplingParameterPSpice[j][0])):  # Number of In's
                         substruct_in = {}
